@@ -15,7 +15,7 @@ from invenio_records_rest.schemas.fields.generated import GenFunction
 
 def pid_from_context(_, context, **kwargs):
     """Get PID from marshmallow context."""
-    pid = (context or {}).get('pid')
+    pid = (context or {}).get("pid")
     return pid.pid_value if pid else missing
 
 
@@ -27,6 +27,6 @@ class PersistentIdentifier(GenFunction):
 
     def __init__(self, *args, **kwargs):
         """Initialize field."""
-        super(PersistentIdentifier, self).__init__(
-            serialize=pid_from_context, deserialize=pid_from_context,
-            *args, **kwargs)
+        super().__init__(
+            serialize=pid_from_context, deserialize=pid_from_context, *args, **kwargs
+        )
