@@ -8,8 +8,6 @@
 
 """Record serialization."""
 
-from __future__ import absolute_import, print_function
-
 from ..schemas import RecordSchemaJSONV1
 from .json import JSONSerializer
 from .response import record_responsify, search_responsify
@@ -17,8 +15,8 @@ from .response import record_responsify, search_responsify
 json_v1 = JSONSerializer(RecordSchemaJSONV1)
 """JSON v1 serializer."""
 
-json_v1_response = record_responsify(json_v1, 'application/json')
+json_v1_response = record_responsify(json_v1, "application/json")
 """JSON response builder that uses the JSON v1 serializer."""
 
-json_v1_search = search_responsify(json_v1, 'application/json')
+json_v1_search = search_responsify(json_v1, "application/json")
 """JSON search response builder that uses the JSON v1 serializer."""
