@@ -11,8 +11,6 @@
 Responsible for creating a HTTP response given the output of a serializer.
 """
 
-from __future__ import absolute_import, print_function
-
 from flask import current_app
 
 
@@ -23,10 +21,12 @@ def record_responsify(serializer, mimetype):
     :param mimetype: MIME type of response.
     :returns: Function that generates a record HTTP response.
     """
+
     def view(pid, record, code=200, headers=None, links_factory=None):
         response = current_app.response_class(
             serializer.serialize(pid, record, links_factory=links_factory),
-            mimetype=mimetype)
+            mimetype=mimetype,
+        )
         response.status_code = code
         response.cache_control.no_cache = True
         response.set_etag(str(record.revision_id))
@@ -49,13 +49,24 @@ def search_responsify(serializer, mimetype):
     :param mimetype: MIME type of response.
     :returns: Function that generates a record HTTP response.
     """
-    def view(pid_fetcher, search_result, code=200, headers=None, links=None,
-             item_links_factory=None):
+
+    def view(
+        pid_fetcher,
+        search_result,
+        code=200,
+        headers=None,
+        links=None,
+        item_links_factory=None,
+    ):
         response = current_app.response_class(
-            serializer.serialize_search(pid_fetcher, search_result,
-                                        links=links,
-                                        item_links_factory=item_links_factory),
-            mimetype=mimetype)
+            serializer.serialize_search(
+                pid_fetcher,
+                search_result,
+                links=links,
+                item_links_factory=item_links_factory,
+            ),
+            mimetype=mimetype,
+        )
         response.status_code = code
         if headers is not None:
             response.headers.extend(headers)
@@ -75,7 +86,10 @@ def add_link_header(response, links):
     :param links: Dictionary of links
     """
     if links is not None:
-        response.headers.extend({
-            'Link': ', '.join([
-                '<{0}>; rel="{1}"'.format(l, r) for r, l in links.items()])
-        })
+        response.headers.extend(
+            {
+                "Link": ", ".join(
+                    ['<{0}>; rel="{1}"'.format(l, r) for r, l in links.items()]
+                )
+            }
+        )
